@@ -9,9 +9,10 @@
 #'   unknown species names to higher taxon ranks (e.g. genus).
 #' @param verbose logical. If FALSE (default), warnings and messages are
 #'   suppressed.
-#' @param fuzzy logical. If FALSE (default), names are only resolved to exactly
-#'   matching taxa on GBIF taxonomy service. Setting to TRUE may produce matches
-#'   when failing otherwise.
+#' @param fuzzy logical. Defaults to TRUE to deal with misspelled names. May
+#'   produce wrong assignments in case of very similar taxon names. If FALSE
+#'   (default), names are only resolved to exactly matching taxa on GBIF
+#'   taxonomy service.
 #' @param conf_threshold numerical, ranging from 0 to 100 (default value = 90).
 #'   Defines the confidence level of the request to be accepted. To cover for
 #'   misspellings and errors, could go as low as 50.
@@ -82,7 +83,7 @@ get_gbif_taxonomy <- function(x,
     
     if(nrow(temp[[i]]) == 0) {
       warning_i <- paste("No matching species concept!")
-      temp[[i]] <- data.frame(scientificName = x[i], matchtype = "NONE", status = "NA", rank = "species", stringsAsFactors = FALSE)
+      temp[[i]] <- data.frame(verbatimScientificName = x[i], matchtype = "NONE", status = "NA", rank = "species", stringsAsFactors = FALSE)
       
     }
     
@@ -100,7 +101,7 @@ get_gbif_taxonomy <- function(x,
     if(!is.null(conf_threshold) & nrow(temp[[i]]) > 0) {
       temp[[i]] <- subset(temp[[i]], confidence >= conf_threshold)
       if(nrow(temp[[i]]) == 0) {
-        temp[[i]] <- data.frame(scientificName = x[i], matchtype = "NONE", status = "NA", rank = "species", stringsAsFactors = FALSE)
+        temp[[i]] <- data.frame(verbatimScientificName = x[i], matchtype = "NONE", status = "NA", rank = "species", stringsAsFactors = FALSE)
         warning_i <- paste(warning_i, "No match! Check spelling or lower confidence threshold!")
       }
     }
@@ -187,7 +188,7 @@ get_gbif_taxonomy <- function(x,
         
       } else {
         
-        temp[[i]] <- data.frame(scientificName = x[i], matchtype = "NONE", rank = "subspecies", stringsAsFactors = FALSE)
+        temp[[i]] <- data.frame(verbatimScientificName = x[i], matchtype = "NONE", rank = "subspecies", stringsAsFactors = FALSE)
         warning_i <- paste(warning_i, "No mapping of subspecies name to species was possible!", sep = " ")
       }
       
@@ -198,7 +199,7 @@ get_gbif_taxonomy <- function(x,
         temp[[i]] <- subset(temp[[i]], temp[[i]]$confidence == max(temp[[i]]$confidence))
         warning_i <- paste(warning_i, "No matching species concept! Entry has been mapped to higher taxonomic level.")
       } else {
-        temp[[i]] <- data.frame(scientificName = x[i], matchtype = "NONE", rank = "highertaxon", stringsAsFactors = FALSE)
+        temp[[i]] <- data.frame(verbatimScientificName = x[i], matchtype = "NONE", rank = "highertaxon", stringsAsFactors = FALSE)
         warning_i <- paste("No matching species concept!", warning_i)
       }
     } 
@@ -208,9 +209,9 @@ get_gbif_taxonomy <- function(x,
     if(temp[[i]]$matchtype != "NONE") {
       
       temp[[i]] <- data.frame(
-        scientificName = x[i], 
+        verbatimScientificName = x[i], 
         synonym = synonym_i, 
-        scientificNameStd = temp[[i]]$canonicalname, 
+        scientificName = temp[[i]]$canonicalname, 
         author = sub(paste0(temp[[i]]$canonicalname," "), "", temp[[i]]$scientificname),
         taxonRank = temp[[i]]$rank,
         confidence = temp[[i]]$confidence,
@@ -226,7 +227,7 @@ get_gbif_taxonomy <- function(x,
         stringsAsFactors = FALSE
       )
     } else {
-      temp[[i]] <- data.frame(scientificName = x[i], warnings = NA, stringsAsFactors = FALSE )
+      temp[[i]] <- data.frame(verbatimScientificName = x[i], warnings = NA, stringsAsFactors = FALSE )
     }
     
     temp[[i]]$warnings <- warning_i
